@@ -6,8 +6,9 @@ from collections import deque, Counter
 import ctypes
 import json
 import numpy as np
+from onnx import TensorProto
 from ...common._apply_operation import (
-    apply_div, apply_reshape, apply_sub, apply_cast, apply_identity, apply_clip)
+    apply_div, apply_reshape, apply_sub, apply_cast, apply_identity)
 from ...common._registration import register_converter
 from ...common.tree_ensemble import get_default_tree_classifier_attribute_pairs
 from ....proto import onnx_proto
@@ -364,6 +365,64 @@ def dump_booster_model(self, num_iteration=None, start_iteration=0,
     return ret, info
 
 
+def _split_tree_ensemble_atts(attrs, split):
+    """
+    Splits the attributes of a TreeEnsembleRegressor into
+    multiple trees in order to do the summation in double instead of floats.
+    """
+    trees_id = list(sorted(set(attrs['nodes_treeids'])))
+    results = []
+    index = 0
+    while index < len(trees_id):
+        index2 = min(index + split, len(trees_id))
+        subset = set(trees_id[index: index2])
+
+        indices_node = []
+        indices_target = []
+        for j, v in enumerate(attrs['nodes_treeids']):
+            if v in subset:
+                indices_node.append(j)
+        for j, v in enumerate(attrs['target_treeids']):
+            if v in subset:
+                indices_target.append(j)
+
+        if (len(indices_node) >= len(attrs['nodes_treeids']) or
+                len(indices_target) >= len(attrs['target_treeids'])):
+            raise RuntimeError(  # pragma: no cover
+                "Initial attributes are not consistant."
+                "\nindex=%r index2=%r subset=%r"
+                "\nnodes_treeids=%r\ntarget_treeids=%r"
+                "\nindices_node=%r\nindices_target=%r" % (
+                    index, index2, subset,
+                    attrs['nodes_treeids'], attrs['target_treeids'],
+                    indices_node, indices_target))
+
+        ats = {}
+        for name, att in attrs.items():
+            if name == 'nodes_treeids':
+                new_att = [att[i] for i in indices_node]
+                new_att = [i - att[0] for i in new_att]
+            elif name == 'target_treeids':
+                new_att = [att[i] for i in indices_target]
+                new_att = [i - att[0] for i in new_att]
+            elif name.startswith("nodes_"):
+                new_att = [att[i] for i in indices_node]
+                assert len(new_att) == len(indices_node)
+            elif name.startswith("target_"):
+                new_att = [att[i] for i in indices_target]
+                assert len(new_att) == len(indices_target)
+            elif name == 'name':
+                new_att = "%s%d" % (att, len(results))
+            else:
+                new_att = att
+            ats[name] = new_att
+
+        results.append(ats)
+        index = index2
+
+    return results
+
+
 def convert_lightgbm(scope, operator, container):
     """
     Converters for *lightgbm*.
@@ -385,7 +444,7 @@ def convert_lightgbm(scope, operator, container):
     elif gbm_text['objective'].startswith('multiclass'):
         n_classes = gbm_text['num_class']
         attrs['post_transform'] = 'SOFTMAX'
-    elif gbm_text['objective'].startswith('regression'):
+    elif gbm_text['objective'].startswith(('regression', 'quantile')):
         n_classes = 1  # Regressor has only one output variable
         attrs['post_transform'] = 'NONE'
         attrs['n_targets'] = n_classes
@@ -541,9 +600,32 @@ def convert_lightgbm(scope, operator, container):
             # and TreeEnsembleClassifier have different ONNX attributes
             attrs['target' + k[5:]] = copy.deepcopy(attrs[k])
             del attrs[k]
-        container.add_node(
-            'TreeEnsembleRegressor', operator.input_full_names,
-            output_name, op_domain='ai.onnx.ml', **attrs)
+
+        split = getattr(operator, 'split', None)
+        if split in (None, -1):
+            container.add_node(
+                'TreeEnsembleRegressor', operator.input_full_names,
+                output_name, op_domain='ai.onnx.ml', **attrs)
+        else:
+            tree_attrs = _split_tree_ensemble_atts(attrs, split)
+            tree_nodes = []
+            for i, ats in enumerate(tree_attrs):
+                tree_name = scope.get_unique_variable_name('tree%d' % i)
+                container.add_node(
+                    'TreeEnsembleRegressor', operator.input_full_names,
+                    tree_name, op_domain='ai.onnx.ml', **ats)
+                cast_name = scope.get_unique_variable_name('dtree%d' % i)
+                container.add_node(
+                    'Cast', tree_name, cast_name, to=TensorProto.DOUBLE,  # pylint: disable=E1101
+                    name=scope.get_unique_operator_name("dtree%d" % i))
+                tree_nodes.append(cast_name)
+            cast_name = scope.get_unique_variable_name('ftrees')
+            container.add_node(
+                'Sum', tree_nodes, cast_name,
+                name=scope.get_unique_operator_name("sumtree%d" % len(tree_nodes)))
+            container.add_node(
+                'Cast', cast_name, output_name, to=TensorProto.FLOAT,  # pylint: disable=E1101
+                name=scope.get_unique_operator_name("dtree%d" % i))
         if gbm_model.boosting_type == 'rf':
             denominator_name = scope.get_unique_variable_name('denominator')
 
@@ -722,12 +804,15 @@ def convert_lgbm_zipmap(scope, operator, container):
                            operator.outputs[1].full_name,
                            op_domain='ai.onnx.ml', **zipmap_attrs)
     else:
-        # This should be apply_identity but optimization fails in
-        # onnxconverter-common when trying to remove identity nodes.
-        apply_clip(scope, operator.inputs[1].full_name,
-                   operator.outputs[1].full_name, container,
-                   min=np.array([0], dtype=np.float32),
-                   max=np.array([1], dtype=np.float32))
+        # onnxconverter-common when trying to remove identity nodes
+        # if node identity is used.
+        one = scope.get_unique_variable_name('one')
+
+        container.add_initializer(
+            one, onnx_proto.TensorProto.FLOAT, [], [1])
+        container.add_node(
+            'Mul', [operator.inputs[1].full_name, one],
+            operator.outputs[1].full_name)
 
 
 register_converter('LgbmClassifier', convert_lightgbm)
