@@ -1,13 +1,18 @@
 # SPDX-License-Identifier: Apache-2.0
 
-import numpy
 import pickle
 import os
 import warnings
+import numpy
+from onnx.defs import onnx_opset_version
+from onnxconverter_common.onnx_ex import DEFAULT_OPSET_NUMBER
 from ..convert.common.data_types import FloatTensorType
 from .utils_backend import compare_backend, extract_options, evaluate_condition, is_backend_enabled
 
 
+TARGET_OPSET = min(DEFAULT_OPSET_NUMBER, onnx_opset_version())
+
+
 def dump_data_and_model(data, model, onnx=None, basename="model", folder=None,
                         inputs=None, backend="onnxruntime", context=None,
                         allow_failure=None, verbose=False):
@@ -248,7 +253,8 @@ def dump_one_class_classification(model, suffix="", folder=None, allow_failure=N
     X = numpy.array(X, dtype=numpy.float32)
     y = [1, 1, 1]
     model.fit(X, y)
-    model_onnx, prefix = convert_model(model, 'one_class', [('input', FloatTensorType([None, 2]))])
+    model_onnx, prefix = convert_model(model, 'one_class', [('input', FloatTensorType([None, 2]))],
+                                       target_opset=TARGET_OPSET)
     return dump_data_and_model(X, model, model_onnx, folder=folder, allow_failure=allow_failure,
                                basename=prefix + "One" + model.__class__.__name__ + suffix)
 
@@ -274,7 +280,8 @@ def dump_binary_classification(model, suffix="", folder=None, allow_failure=None
     X = numpy.array(X, dtype=numpy.float32)
     y = [0, 1, 0]
     model.fit(X, y)
-    model_onnx, prefix = convert_model(model, 'tree-based binary classifier', [('input', FloatTensorType([None, 2]))])
+    model_onnx, prefix = convert_model(model, 'tree-based binary classifier', [('input', FloatTensorType([None, 2]))],
+                                       target_opset=TARGET_OPSET)
     dump_data_and_model(X, model, model_onnx, folder=folder, allow_failure=allow_failure,
                         basename=prefix + "Bin" + model.__class__.__name__ + suffix,
                         verbose=verbose)
@@ -299,7 +306,8 @@ def dump_multiple_classification(model, suffix="", folder=None, allow_failure=No
     X = numpy.array(X, dtype=numpy.float32)
     y = [0, 1, 2, 1, 1, 2]
     model.fit(X, y)
-    model_onnx, prefix = convert_model(model, 'tree-based multi-output regressor', [('input', FloatTensorType([None, 2]))])
+    model_onnx, prefix = convert_model(model, 'tree-based multi-output regressor', [('input', FloatTensorType([None, 2]))],
+                                       target_opset=TARGET_OPSET)
     dump_data_and_model(X, model, model_onnx, folder=folder, allow_failure=allow_failure,
                         basename=prefix + "Mcl" + model.__class__.__name__ + suffix)
 
@@ -324,7 +332,8 @@ def dump_multiple_regression(model, suffix="", folder=None, allow_failure=None):
     X = numpy.array(X, dtype=numpy.float32)
     y = numpy.array([[100, 50], [100, 49], [100, 99]], dtype=numpy.float32)
     model.fit(X, y)
-    model_onnx, prefix = convert_model(model, 'tree-based multi-output regressor', [('input', FloatTensorType([None, 2]))])
+    model_onnx, prefix = convert_model(model, 'tree-based multi-output regressor', [('input', FloatTensorType([None, 2]))],
+                                       target_opset=TARGET_OPSET)
     dump_data_and_model(X, model, model_onnx, folder=folder, allow_failure=allow_failure,
                         basename=prefix + "MRg" + model.__class__.__name__ + suffix)
 
@@ -350,7 +359,8 @@ def dump_single_regression(model, suffix="", folder=None, allow_failure=None):
     X = numpy.array(X, dtype=numpy.float32)
     y = numpy.array([100, -10, 50], dtype=numpy.float32)
     model.fit(X, y)
-    model_onnx, prefix = convert_model(model, 'tree-based regressor', [('input', FloatTensorType([None, 2]))])
+    model_onnx, prefix = convert_model(model, 'tree-based regressor', [('input', FloatTensorType([None, 2]))],
+                                       target_opset=TARGET_OPSET)
     dump_data_and_model(X, model, model_onnx, folder=folder, allow_failure=allow_failure,
                         basename=prefix + "Reg" + model.__class__.__name__ + suffix)
 
